<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

if ( ! function_exists( 'dark_music_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Dark Music Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function dark_music_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'dark_music_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'dark_music_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Dark Music Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function dark_music_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'dark_music_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'dark_music_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Dark Music Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function dark_music_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'dark_music_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if slider section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[slider_content_type]' )->value();
	return dark_music_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[slider_content_type]' )->value();
	return dark_music_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[slider_content_type]' )->value();
	return dark_music_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is product.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_slider_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[slider_content_type]' )->value();
	return dark_music_pro_is_slider_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if slider section content type is product category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_slider_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[slider_content_type]' )->value();
	return dark_music_pro_is_slider_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if playlist section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_playlist_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[playlist_section_enable]' )->value() );
}


/**
 * Check if about section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[about_content_type]' )->value();
	return dark_music_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[about_content_type]' )->value();
	return dark_music_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[about_content_type]' )->value();
	return dark_music_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if hero content section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_hero_content_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[hero_content_section_enable]' )->value() );
}

/**
 * Check if hero content section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_hero_content_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[hero_content_content_type]' )->value();
	return dark_music_pro_is_hero_content_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero content section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_hero_content_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[hero_content_content_type]' )->value();
	return dark_music_pro_is_hero_content_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero content section content type is custom.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_hero_content_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[hero_content_content_type]' )->value();
	return dark_music_pro_is_hero_content_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[service_content_type]' )->value();
	return dark_music_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[service_content_type]' )->value();
	return dark_music_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[service_content_type]' )->value();
	return dark_music_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[service_content_type]' )->value();
	return dark_music_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest release section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_latest_release_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[latest_release_section_enable]' )->value() );
}

/**
 * Check if latest release section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_latest_release_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[latest_release_content_type]' )->value();
	return dark_music_pro_is_latest_release_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest release section seperator.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_latest_release_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[latest_release_content_type]' )->value();
	return dark_music_pro_is_latest_release_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if latest release section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_latest_release_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[latest_release_content_type]' )->value();
	return dark_music_pro_is_latest_release_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest release section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_latest_release_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[latest_release_content_type]' )->value();
	return dark_music_pro_is_latest_release_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest release section content type is product.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_latest_release_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[latest_release_content_type]' )->value();
	return dark_music_pro_is_latest_release_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest release section content type is product category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_latest_release_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[latest_release_content_type]' )->value();
	return dark_music_pro_is_latest_release_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[cta_content_type]' )->value();
	return dark_music_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[cta_content_type]' )->value();
	return dark_music_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[cta_content_type]' )->value();
	return dark_music_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if event section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[event_content_type]' )->value();
	return dark_music_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[event_content_type]' )->value();
	return dark_music_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[event_content_type]' )->value();
	return dark_music_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_event_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[event_content_type]' )->value();
	return dark_music_pro_is_event_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_event_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[event_content_type]' )->value();
	return dark_music_pro_is_event_section_enable( $control ) && ( 'event-category' == $content_type );
}

/**
 * Check if gallery section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[gallery_content_type]' )->value();
	return dark_music_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[gallery_content_type]' )->value();
	return dark_music_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[gallery_content_type]' )->value();
	return dark_music_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is product.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_gallery_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[gallery_content_type]' )->value();
	return dark_music_pro_is_gallery_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if gallery section content type is product category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_gallery_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[gallery_content_type]' )->value();
	return dark_music_pro_is_gallery_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[testimonial_content_type]' )->value();
	return dark_music_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[testimonial_content_type]' )->value();
	return dark_music_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[testimonial_content_type]' )->value();
	return dark_music_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[testimonial_content_type]' )->value();
	return dark_music_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[testimonial_content_type]' )->value();
	return dark_music_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[testimonial_content_type]' )->value();
	return dark_music_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if client section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_client_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[client_section_enable]' )->value() );
}

/**
 * Check if product section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[product_content_type]' )->value();
	return dark_music_pro_is_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[product_content_type]' )->value();
	return dark_music_pro_is_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[blog_content_type]' )->value();
	return dark_music_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[blog_content_type]' )->value();
	return dark_music_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[blog_content_type]' )->value();
	return dark_music_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[blog_content_type]' )->value();
	return dark_music_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[subscription_section_enable]' )->value() ) && class_exists( 'Jetpack' );
}


/**
 * Check if team section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[team_content_type]' )->value();
	return dark_music_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[team_content_type]' )->value();
	return dark_music_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[team_content_type]' )->value();
	return dark_music_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}




/**
 * Check if course section is enabled.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'dark_music_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[course_content_type]' )->value();
	return dark_music_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[course_content_type]' )->value();
	return dark_music_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since Dark Music Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function dark_music_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'dark_music_pro_theme_options[course_content_type]' )->value();
	return dark_music_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}
