<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'dark_music_pro_about_section', array(
	'title'             => esc_html__( 'About Us','dark-music-pro' ),
	'description'       => esc_html__( 'About Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_about_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[about_section_enable]',
    ) );
}



// about subtitle setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[about_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_about_section',
	'active_callback' 	=> 'dark_music_pro_is_about_section_enable',
	'type'				=> 'text',
) );


// About content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'dark-music-pro' ),
		'post' 		=> esc_html__( 'Post', 'dark-music-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'dark-music-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_page',
) );

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_about_section',
	'choices'			=> dark_music_pro_page_choices(),
	'active_callback'	=> 'dark_music_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_page',
) );

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_about_section',
	'choices'			=> dark_music_pro_post_choices(),
	'active_callback'	=> 'dark_music_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_about_section',
	'active_callback' 	=> 'dark_music_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );


// about description setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_about_section',
	'active_callback' 	=> 'dark_music_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );



// about image setting and control.
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dark_music_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'dark-music-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'dark-music-pro' ), 512, 520 ),
		'section'     		=> 'dark_music_pro_about_section',
		'active_callback'	=> 'dark_music_pro_is_about_section_content_custom_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_about_section',
	'active_callback' 	=> 'dark_music_pro_is_about_section_enable',
	'type'				=> 'text',
) );


// about btn link setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_about_section',
	'active_callback' 	=> 'dark_music_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );


