<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'dark_music_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','dark-music-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_blog_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[blog_section_enable]', array(
		'selector'            => '.blog-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[blog_section_enable]',
    ) );
}


// blog title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_blog_section',
	'active_callback' 	=> 'dark_music_pro_is_blog_section_enable',
	'type'				=> 'text',
) );


// blog subtitle setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[blog_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_blog_section',
	'active_callback' 	=> 'dark_music_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// blog btn title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[blog_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_blog_section',
	'active_callback' 	=> 'dark_music_pro_is_blog_section_enable',
	'type'				=> 'text',
) );


// Blog content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'dark-music-pro' ),
		'post' 		=> esc_html__( 'Post', 'dark-music-pro' ),
		'category' 	=> esc_html__( 'Category', 'dark-music-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'dark-music-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'dark_music_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_blog_section',
	'active_callback'   => 'dark_music_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_blog_section',
		'choices'			=> dark_music_pro_page_choices(),
		'active_callback'	=> 'dark_music_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_blog_section',
		'choices'			=> dark_music_pro_post_choices(),
		'active_callback'	=> 'dark_music_pro_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'dark_music_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Category_Control( $wp_customize,'dark_music_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'dark_music_pro_is_blog_section_content_recent_enable'
) ) );
