<?php
/**
 * client Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add client section
$wp_customize->add_section( 'dark_music_pro_client_section', array(
	'title'             => esc_html__( 'Client','dark-music-pro' ),
	'description'       => esc_html__( 'Client Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// client content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[client_section_enable]', array(
	'default'			=> 	$options['client_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[client_section_enable]', array(
	'label'             => esc_html__( 'client Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_client_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[client_section_enable]', array(
		'selector'            => '.client-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[client_section_enable]',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[client_count]', array(
	'default'          	=> $options['client_count'],
	'sanitize_callback' => 'dark_music_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[client_count]', array(
	'label'             => esc_html__( 'Number of clients', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_client_section',
	'active_callback'   => 'dark_music_pro_is_client_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['client_count']; $i++ ) :
	// client image setting and control.
	$wp_customize->add_setting( 'dark_music_pro_theme_options[client_image_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dark_music_pro_theme_options[client_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Client Logo %d', 'dark-music-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'dark-music-pro' ), 200, 200 ),
			'section'     		=> 'dark_music_pro_client_section',
			'active_callback'	=> 'dark_music_pro_is_client_section_enable',
	) ) );

	// client position setting and control
	$wp_customize->add_setting( 'dark_music_pro_theme_options[client_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'dark_music_pro_theme_options[client_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Client Link %d', 'dark-music-pro' ), $i ),
		'section'        	=> 'dark_music_pro_client_section',
		'active_callback' 	=> 'dark_music_pro_is_client_section_enable',
		'type'				=> 'url',
	) );

	// client hr setting and control
	$wp_customize->add_setting( 'dark_music_pro_theme_options[client_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Customize_Horizontal_Line( $wp_customize, 'dark_music_pro_theme_options[client_hr_'. $i .']',
		array(
			'section'         => 'dark_music_pro_client_section',
			'active_callback' => 'dark_music_pro_is_client_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

