<?php
/**
 * course Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add course section
$wp_customize->add_section( 'dark_music_pro_course_section', array(
	'title'             => esc_html__( 'course','dark-music-pro' ),
	'description'       => esc_html__( 'course Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// course content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[course_section_enable]', array(
	'default'			=> 	$options['course_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[course_section_enable]', array(
	'label'             => esc_html__( 'course Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_course_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[course_section_enable]', array(
		'selector'            => '#course-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[course_section_enable]',
    ) );
}


// course title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[course_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[course_title]', array(
	'label'           	=> esc_html__( 'Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_course_section',
	'active_callback' 	=> 'dark_music_pro_is_course_section_enable',
	'type'				=> 'text',
) );


// course subtitle setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[course_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[course_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_course_section',
	'active_callback' 	=> 'dark_music_pro_is_course_section_enable',
	'type'				=> 'text',
) );

// course btn title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[course_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[course_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_course_section',
	'active_callback' 	=> 'dark_music_pro_is_course_section_enable',
	'type'				=> 'text',
) );


// course content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[course_content_type]', array(
	'default'          	=> $options['course_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[course_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_course_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_course_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'dark-music-pro' ),
		'post' 		=> esc_html__( 'Post', 'dark-music-pro' ),
		'category' 	=> esc_html__( 'Category', 'dark-music-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[course_count]', array(
	'default'          	=> $options['course_count'],
	'sanitize_callback' => 'dark_music_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[course_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_course_section',
	'active_callback'   => 'dark_music_pro_is_course_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['course_count']; $i++ ) :
	// course pages drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[course_content_page_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[course_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_course_section',
		'choices'			=> dark_music_pro_page_choices(),
		'active_callback'	=> 'dark_music_pro_is_course_section_content_page_enable',
	) ) );

	// course posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[course_content_post_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[course_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_course_section',
		'choices'			=> dark_music_pro_post_choices(),
		'active_callback'	=> 'dark_music_pro_is_course_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[course_content_category]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[course_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_course_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_course_section_content_category_enable'
) ) );

