<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'dark_music_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery','dark-music-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_gallery_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[gallery_section_enable]', array(
		'selector'            => '#gallery-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[gallery_section_enable]',
    ) );
}


// gallery title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_gallery_section',
	'active_callback' 	=> 'dark_music_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// gallery subtitle setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[gallery_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[gallery_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_gallery_section',
	'active_callback' 	=> 'dark_music_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Gallery content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_gallery_section_enable',
	'choices'			=> dark_music_pro_gallery_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'dark_music_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Gallery', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_gallery_section',
	'active_callback'   => 'dark_music_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_gallery_section',
		'choices'			=> dark_music_pro_page_choices(),
		'active_callback'	=> 'dark_music_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_gallery_section',
		'choices'			=> dark_music_pro_post_choices(),
		'active_callback'	=> 'dark_music_pro_is_gallery_section_content_post_enable',
	) ) );



endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_gallery_section_content_category_enable'
) ) );

