<?php
/**
 * Hero Content Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add Hero Content section
$wp_customize->add_section( 'dark_music_pro_hero_content_section', array(
	'title'             => esc_html__( 'Hero Content','dark-music-pro' ),
	'description'       => esc_html__( 'Hero Content Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// Hero Content content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[hero_content_section_enable]', array(
	'default'			=> 	$options['hero_content_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[hero_content_section_enable]', array(
	'label'             => esc_html__( 'Hero Content Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_hero_content_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[hero_content_section_enable]', array(
		'selector'            => '.hero-content-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[hero_content_section_enable]',
    ) );
}


$wp_customize->add_setting( 'dark_music_pro_theme_options[hero_content_bg_image]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'dark_music_pro_theme_options[hero_content_bg_image]',
		array(
		'label'       		=> esc_html__( 'Bg Image', 'dark-music-pro' ),
		'section'     		=> 'dark_music_pro_hero_content_section',
		'active_callback'	=> 'dark_music_pro_is_hero_content_section_enable',
) ) );


// hero_content subtitle setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[hero_content_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_content_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[hero_content_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_hero_content_section',
	'active_callback' 	=> 'dark_music_pro_is_hero_content_section_enable',
	'type'				=> 'text',
) );

// Hero Content content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[hero_content_content_type]', array(
	'default'          	=> $options['hero_content_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[hero_content_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_hero_content_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_hero_content_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'dark-music-pro' ),
		'post' 		=> esc_html__( 'Post', 'dark-music-pro' ),
	),
) );

// hero_content pages drop down chooser control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[hero_content_content_page]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_page',
) );

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[hero_content_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_hero_content_section',
	'choices'			=> dark_music_pro_page_choices(),
	'active_callback'	=> 'dark_music_pro_is_hero_content_section_content_page_enable',
) ) );

// hero_content posts drop down chooser control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[hero_content_content_post]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_page',
) );

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[hero_content_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_hero_content_section',
	'choices'			=> dark_music_pro_post_choices(),
	'active_callback'	=> 'dark_music_pro_is_hero_content_section_content_post_enable',
) ) );



// video url setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[hero_content_video]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[hero_content_video]', array(
	'label'           	=> esc_html__( 'Featured Video', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Input video code from youtube. eg. https://www.youtube.com/watch?v=sXPmLE_KELo code after v "sXPmLE_KELo"', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_hero_content_section',
	'active_callback' 	=> 'dark_music_pro_is_hero_content_section_enable',
	'type'				=> 'text',
) );