<?php
/**
 * Latest Release Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add Latest Release section
$wp_customize->add_section( 'dark_music_pro_latest_release_section', array(
	'title'             => esc_html__( 'Latest Release','dark-music-pro' ),
	'description'       => esc_html__( 'Latest Release Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// Latest Release content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_section_enable]', array(
	'default'			=> 	$options['latest_release_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[latest_release_section_enable]', array(
	'label'             => esc_html__( 'Latest Release Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_latest_release_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[latest_release_section_enable]', array(
		'selector'            => '.latest-release-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[latest_release_section_enable]',
    ) );
}


// latest_release title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_release_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[latest_release_title]', array(
	'label'           	=> esc_html__( 'Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_latest_release_section',
	'active_callback' 	=> 'dark_music_pro_is_latest_release_section_enable',
	'type'				=> 'text',
) );

// latest_release subtitle setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_release_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[latest_release_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_latest_release_section',
	'active_callback' 	=> 'dark_music_pro_is_latest_release_section_enable',
	'type'				=> 'text',
) );

// latest_release btn_title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_release_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[latest_release_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_latest_release_section',
	'active_callback' 	=> 'dark_music_pro_is_latest_release_section_enable',
	'type'				=> 'text',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_count]', array(
	'default'          	=> $options['latest_release_count'],
	'sanitize_callback' => 'dark_music_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[latest_release_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_latest_release_section',
	'active_callback'   => 'dark_music_pro_is_latest_release_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// latest_release posts drop down chooser control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_hr]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Dark_Music_Pro_Customize_Horizontal_Line( $wp_customize, 'dark_music_pro_theme_options[latest_release_hr]', array(
	'type'				=> 'hr',
	'section'           => 'dark_music_pro_latest_release_section',
	'active_callback'	=> 'dark_music_pro_is_latest_release_section_enable',
) ) );

// Latest Release content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_content_type]', array(
	'default'          	=> $options['latest_release_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[latest_release_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_latest_release_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_latest_release_section_enable',
	'choices'			=> dark_music_pro_latest_release_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[latest_release_content_category]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[latest_release_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_latest_release_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_latest_release_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[latest_release_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[latest_release_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_latest_release_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_latest_release_section_content_product_category_enable'
) ) );

for ( $i = 1; $i <= $options['latest_release_count']; $i++ ) :

	// latest_release posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_content_page_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[latest_release_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_latest_release_section',
		'choices'			=> dark_music_pro_page_choices(),
		'active_callback'	=> 'dark_music_pro_is_latest_release_section_content_page_enable',
	) ) );

	// latest_release posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_content_post_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[latest_release_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_latest_release_section',
		'choices'			=> dark_music_pro_post_choices(),
		'active_callback'	=> 'dark_music_pro_is_latest_release_section_content_post_enable',
	) ) );

	// latest_release posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_content_product_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[latest_release_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_latest_release_section',
		'choices'			=> dark_music_pro_product_choices(),
		'active_callback'	=> 'dark_music_pro_is_latest_release_section_content_product_enable',
	) ) );

	// latest_release subtitle setting and control
	$wp_customize->add_setting( 'dark_music_pro_theme_options[latest_release_post_subtitle_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'dark_music_pro_theme_options[latest_release_post_subtitle_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Post Sub Title %d', 'dark-music-pro' ), $i ),
		'section'        	=> 'dark_music_pro_latest_release_section',
		'active_callback' 	=> 'dark_music_pro_is_latest_release_section_enable',
		'type'				=> 'text',
	) );

endfor;
