<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'dark_music_pro_service_section', array(
	'title'             => esc_html__( 'Services','dark-music-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_service_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[service_section_enable]', array(
		'selector'            => '#service-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[service_section_enable]',
    ) );
}


// service title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_service_section',
	'active_callback' 	=> 'dark_music_pro_is_service_section_enable',
	'type'				=> 'text',
) );


// service subtitle setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[service_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[service_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_service_section',
	'active_callback' 	=> 'dark_music_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// service title setting and control
$wp_customize->add_setting( 'dark_music_pro_theme_options[service_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[service_btn_title]', array(
	'label'           	=> esc_html__( 'Title', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_service_section',
	'active_callback' 	=> 'dark_music_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Service content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'dark-music-pro' ),
		'post' 		=> esc_html__( 'Post', 'dark-music-pro' ),
		'category' 	=> esc_html__( 'Category', 'dark-music-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'dark_music_pro_sanitize_number_range',
	'validate_callback' => 'dark_music_pro_validate_service_count',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Services', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_service_section',
	'active_callback'   => 'dark_music_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Icon_Picker( $wp_customize, 'dark_music_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_service_section',
		'active_callback'	=> 'dark_music_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_service_section',
		'choices'			=> dark_music_pro_page_choices(),
		'active_callback'	=> 'dark_music_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_service_section',
		'choices'			=> dark_music_pro_post_choices(),
		'active_callback'	=> 'dark_music_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'dark_music_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Customize_Horizontal_Line( $wp_customize, 'dark_music_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'dark_music_pro_service_section',
			'active_callback' => 'dark_music_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_service_section_content_category_enable'
) ) );
