<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'dark_music_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','dark-music-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'dark-music-pro' ),
	'panel'             => 'dark_music_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'dark_music_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Dark_Music_Pro_Switch_Control( $wp_customize, 'dark_music_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_slider_section',
	'on_off_label' 		=> dark_music_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'dark_music_pro_theme_options[slider_section_enable]', array(
		'selector'            => '.slider-section .tooltiptext',
		'settings'            => 'dark_music_pro_theme_options[slider_section_enable]',
    ) );
}


$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[slider_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_slider_section',
	'active_callback' 	=> 'dark_music_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_alt_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_alt_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[slider_alt_btn_title]', array(
	'label'           	=> esc_html__( 'Alt Button Label', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_slider_section',
	'active_callback' 	=> 'dark_music_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_alt_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[slider_alt_btn_url]', array(
	'label'           	=> esc_html__( 'Alt Button Url', 'dark-music-pro' ),
	'section'        	=> 'dark_music_pro_slider_section',
	'active_callback' 	=> 'dark_music_pro_is_slider_section_enable',
	'type'				=> 'url',
) );



// Slider content type control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'dark_music_pro_sanitize_select',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'dark_music_pro_is_slider_section_enable',
	'choices'			=> dark_music_pro_slider_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'dark_music_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'dark_music_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'dark-music-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_slider_section',
	'active_callback'   => 'dark_music_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_slider_section',
		'choices'			=> dark_music_pro_page_choices(),
		'active_callback'	=> 'dark_music_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_slider_section',
		'choices'			=> dark_music_pro_post_choices(),
		'active_callback'	=> 'dark_music_pro_is_slider_section_content_post_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'dark_music_pro_theme_options[slider_content_product_' . $i . ']', array(
		'sanitize_callback' => 'dark_music_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Chooser( $wp_customize, 'dark_music_pro_theme_options[slider_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'dark-music-pro' ), $i ),
		'section'           => 'dark_music_pro_slider_section',
		'choices'			=> dark_music_pro_product_choices(),
		'active_callback'	=> 'dark_music_pro_is_slider_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'dark_music_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_slider_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'dark_music_pro_theme_options[slider_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Dark_Music_Pro_Dropdown_Taxonomies_Control( $wp_customize,'dark_music_pro_theme_options[slider_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'dark-music-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'dark-music-pro' ),
	'section'           => 'dark_music_pro_slider_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'dark_music_pro_is_slider_section_content_product_category_enable'
) ) );