<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function dark_music_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'dark-music-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function dark_music_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'dark-music-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function dark_music_pro_trip_choices() {
    if ( ! class_exists( 'WP_Travel' ) ) {
        return;
    }
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'dark-music-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function dark_music_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'dark-music-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function dark_music_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'dark-music-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of audio for post choices.
 * @return Array Array of post ids and name.
 */
function dark_music_pro_audio_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'attachment', 'post_mime_type' => 'audio' ) );
    $choices = array();
    $choices[0] = esc_html__( '--None--', 'dark-music-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'dark_music_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function dark_music_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'dark-music-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'dark_music_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function dark_music_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'dark-music-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'dark-music-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'dark-music-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'dark-music-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'dark-music-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'dark-music-pro' ),
        );

        $output = apply_filters( 'dark_music_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'dark_music_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function dark_music_pro_site_layout() {
        $dark_music_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'dark_music_pro_site_layout', $dark_music_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'dark_music_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function dark_music_pro_selected_sidebar() {
        $dark_music_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'dark-music-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'dark-music-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'dark-music-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'dark-music-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'dark-music-pro' ),
        );

        $output = apply_filters( 'dark_music_pro_selected_sidebar', $dark_music_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'dark_music_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function dark_music_pro_global_sidebar_position() {
        $dark_music_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'dark_music_pro_global_sidebar_position', $dark_music_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'dark_music_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function dark_music_pro_sidebar_position() {
        $dark_music_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'dark_music_pro_sidebar_position', $dark_music_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'dark_music_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function dark_music_pro_pagination_options() {
        $dark_music_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'dark-music-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'dark-music-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'dark-music-pro' ),
        );

        $output = apply_filters( 'dark_music_pro_pagination_options', $dark_music_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'dark_music_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function dark_music_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'dark-music-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'dark-music-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'dark-music-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'dark-music-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'dark-music-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'dark-music-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'dark-music-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'dark-music-pro' ),
        );
        return apply_filters( 'dark_music_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'dark_music_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function dark_music_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'dark-music-pro' ),
            'off'       => esc_html__( 'Disable', 'dark-music-pro' )
        );
        return apply_filters( 'dark_music_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'dark_music_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function dark_music_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'dark-music-pro' ),
            'off'       => esc_html__( 'No', 'dark-music-pro' )
        );
        return apply_filters( 'dark_music_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'dark_music_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function dark_music_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Main Slider', 'dark-music-pro' ),
            'playlist'  => esc_html__( 'Playlist', 'dark-music-pro' ),
            'about'     => esc_html__( 'About Us', 'dark-music-pro' ),
            'hero_content' => esc_html__( 'Hero Content', 'dark-music-pro' ),
            'service'   => esc_html__( 'Services', 'dark-music-pro' ),
            'latest_release' => esc_html__( 'Latest Release', 'dark-music-pro' ),
            'cta'       => esc_html__( 'Call to Action', 'dark-music-pro' ),
            'event'     => esc_html__( 'Event', 'dark-music-pro' ),
            'gallery'   => esc_html__( 'Gallery', 'dark-music-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'dark-music-pro' ),
            'promotion' => esc_html__( 'Promotion', 'dark-music-pro' ),
            'product'   => esc_html__( 'Product', 'dark-music-pro' ),
            'artists'   => esc_html__( 'Artists', 'dark-music-pro' ),
            'blog'      => esc_html__( 'Blog', 'dark-music-pro' ),
            'subscription'      => esc_html__( 'Subscription', 'dark-music-pro' ),
        );
        return apply_filters( 'dark_music_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'dark_music_pro_slider_content_type' ) ) :
    /**
     * Slider Options
     * @return array site slider options
     */
    function dark_music_pro_slider_content_type() {
        $dark_music_pro_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'dark-music-pro' ),
            'post'      => esc_html__( 'Post', 'dark-music-pro' ),
            'category'  => esc_html__( 'Category', 'dark-music-pro' ),
        );
        
        $output = apply_filters( 'dark_music_pro_slider_content_type', $dark_music_pro_slider_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'dark_music_pro_latest_release_content_type' ) ) :
    /**
     * Latest Release Options
     * @return array site latest_release options
     */
    function dark_music_pro_latest_release_content_type() {
        $dark_music_pro_latest_release_content_type = array(
            'page'      => esc_html__( 'Page', 'dark-music-pro' ),
            'post'      => esc_html__( 'Post', 'dark-music-pro' ),
            'category'  => esc_html__( 'Category', 'dark-music-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $dark_music_pro_latest_release_content_type = array_merge( $dark_music_pro_latest_release_content_type, array(
                'product'   => esc_html__( 'Product', 'dark-music-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'dark-music-pro' ),
                ) );
        }

        $output = apply_filters( 'dark_music_pro_latest_release_content_type', $dark_music_pro_latest_release_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'dark_music_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function dark_music_pro_event_content_type() {
        $dark_music_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'dark-music-pro' ),
            'post'      => esc_html__( 'Post', 'dark-music-pro' ),
            'category'  => esc_html__( 'Category', 'dark-music-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $dark_music_pro_event_content_type = array_merge( $dark_music_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'dark-music-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'dark-music-pro' ),
                ) );
        }

        $output = apply_filters( 'dark_music_pro_event_content_type', $dark_music_pro_event_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'dark_music_pro_gallery_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function dark_music_pro_gallery_content_type() {
        $dark_music_pro_gallery_content_type = array(
            'page'      => esc_html__( 'Page', 'dark-music-pro' ),
            'post'      => esc_html__( 'Post', 'dark-music-pro' ),
            'category'  => esc_html__( 'Category', 'dark-music-pro' ),
        );

        $output = apply_filters( 'dark_music_pro_gallery_content_type', $dark_music_pro_gallery_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'dark_music_pro_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function dark_music_pro_product_content_type() {
        $dark_music_pro_product_content_type = array(
            'product'   => esc_html__( 'Product', 'dark-music-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'dark-music-pro' ),
        );

        $output = apply_filters( 'dark_music_pro_product_content_type', $dark_music_pro_product_content_type );

        return $output;
    }
endif;