<?php
/**
 * course section
 *
 * This is the template for the content of course section
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */
if ( ! function_exists( 'dark_music_pro_add_course_section' ) ) :
    /**
    * Add course section
    *
    *@since Dark Music Pro 1.0.0
    */
    function dark_music_pro_add_course_section() {
    	$options = dark_music_pro_get_theme_options();
        // Check if course is enabled on frontpage
        $course_enable = apply_filters( 'dark_music_pro_section_status', true, 'course_section_enable' );

        if ( true !== $course_enable ) {
            return false;
        }
        // Get course section details
        $section_details = array();
        $section_details = apply_filters( 'dark_music_pro_filter_course_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render course section now.
        dark_music_pro_render_course_section( $section_details );
    }
endif;

if ( ! function_exists( 'dark_music_pro_get_course_section_details' ) ) :
    /**
    * course section details.
    *
    * @since Dark Music Pro 1.0.0
    * @param array $input course section details.
    */
    function dark_music_pro_get_course_section_details( $input ) {
        $options = dark_music_pro_get_theme_options();

        // Content type.
        $course_content_type  = $options['course_content_type'];
        $course_count = ! empty( $options['course_count'] ) ? $options['course_count'] : 4;
        
        $content = array();
        switch ( $course_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_page_' . $i] ) )
                        $page_ids[] = $options['course_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_post_' . $i] ) )
                        $post_ids[] = $options['course_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['course_content_category'] ) ? $options['course_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $course_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;


            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = dark_music_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// course section content details.
add_filter( 'dark_music_pro_filter_course_section_details', 'dark_music_pro_get_course_section_details' );


if ( ! function_exists( 'dark_music_pro_render_course_section' ) ) :
  /**
   * Start course section
   *
   * @return string course content
   * @since Dark Music Pro 1.0.0
   *
   */
   function dark_music_pro_render_course_section( $content_details = array() ) {
        $options = dark_music_pro_get_theme_options();
        $course_content_type  = $options['course_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="dark_music_pro_course_section">
            <div id="course-section" class="relative page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    dark_music_pro_section_tooltip( 'course-section' );
                    endif; ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['course_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['course_subtitle'] ); ?></p>
                        <?php endif; ?>
                        <?php if ( ! empty( $options['course_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['course_title'] ); ?></h2>
                        <?php endif; ?>                       
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="course-item">
                                  

                                    <div class="entry-container">
                                        <div class="featured-image">
                                            <a href="#"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="course"></a>
                                        </div><!-- .featured-image -->
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->

                                        <?php if ( !empty( $options['course_btn_title'] ) ): ?>
                                            <div class="read-more">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['course_btn_title'] ); ?></a>
                                            </div><!-- .read-more -->
                                        <?php endif ?>
                                        
                                    </div><!-- .entry-container -->
                                </div><!-- .post-wrapper -->
                            </article>
                        <?php endforeach ; ?>
                    </div><!-- .archive-course-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #latest-posts-section -->
        </div>
        
    <?php }
endif;