<?php
/**
 * Hero Content section
 *
 * This is the template for the content of hero content section
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */
if ( ! function_exists( 'dark_music_pro_add_hero_content_section' ) ) :
    /**
    * Add hero content section
    *
    *@since Dark Music Pro 1.0.0
    */
    function dark_music_pro_add_hero_content_section() {
    	$options = dark_music_pro_get_theme_options();
        // Check if hero content is enabled on frontpage
        $hero_content_enable = apply_filters( 'dark_music_pro_section_status', true, 'hero_content_section_enable' );

        if ( true !== $hero_content_enable ) {
            return false;
        }
        // Get hero content section details
        $section_details = array();
        $section_details = apply_filters( 'dark_music_pro_filter_hero_content_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render hero content section now.
        dark_music_pro_render_hero_content_section( $section_details );
    }
endif;

if ( ! function_exists( 'dark_music_pro_get_hero_content_section_details' ) ) :
    /**
    * hero content section details.
    *
    * @since Dark Music Pro 1.0.0
    * @param array $input hero content section details.
    */
    function dark_music_pro_get_hero_content_section_details( $input ) {
        $options = dark_music_pro_get_theme_options();

        // Content type.
        $hero_content_content_type  = $options['hero_content_content_type'];
        
        $content = array();
        switch ( $hero_content_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['hero_content_title'] ) ? $options['hero_content_title'] : '';
                $custom['excerpt']      = ! empty( $options['hero_content_description'] ) ? $options['hero_content_description'] : '';
                $custom['image']        = ! empty( $options['hero_content_image'] ) ? $options['hero_content_image'] : '';
                $custom['url']          = ! empty( $options['hero_content_btn_link'] ) ? $options['hero_content_btn_link'] : '';
                $custom['video']          = ! empty( $options['hero_content_video'] ) ? $options['hero_content_video'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['hero_content_content_page'] ) ? $options['hero_content_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['hero_content_content_post'] ) ? $options['hero_content_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $hero_content_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = dark_music_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                    $page_post['video']     = ! empty( $options['hero_content_video'] ) ? $options['hero_content_video'] : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// hero content section content details.
add_filter( 'dark_music_pro_filter_hero_content_section_details', 'dark_music_pro_get_hero_content_section_details' );


if ( ! function_exists( 'dark_music_pro_render_hero_content_section' ) ) :
  /**
   * Start hero content section
   *
   * @return string hero content content
   * @since Dark Music Pro 1.0.0
   *
   */
   function dark_music_pro_render_hero_content_section( $content_details = array() ) {
        $options = dark_music_pro_get_theme_options();
        $readmore = ! empty( $options['hero_content_btn_title'] ) ? $options['hero_content_btn_title'] : esc_html__( 'Read More', 'dark-music-pro' );

        $bg_image = !empty( $options['hero_content_bg_image'] ) ? $options['hero_content_bg_image'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
            <div id="dark_music_pro_hero_content_section">
                <div id="video-section" class="hero-content-section relative page-section" style="background-image: url('<?php echo esc_url( $bg_image ) ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <?php if ( is_customize_preview()):
                        dark_music_pro_section_tooltip( 'hero-content-section-class' );
                        endif; ?>
                        <div class="section-header">
                            <?php if ( !empty( $options['hero_content_subtitle'] ) ): ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['hero_content_subtitle'] ); ?></p>
                            <?php endif ?>                  
                            <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                        </div><!-- .section-header -->

                        <?php if ( !empty( $content['video'] ) ): ?>
                            <div class="video-wrapper">
                                <iframe width="900" height="506" src="https://www.youtube.com/embed/<?php echo esc_attr( $content['video'] ); ?>" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                            </div><!-- .video-wrapper -->
                        <?php endif ?>                    
                    </div><!-- .wrapper -->
                </div><!-- #video-section -->
            </div>
           
        <?php endforeach;  
    }
endif;
