<?php
/**
 * Latest Release section
 *
 * This is the template for the content of latest_release section
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */
if ( ! function_exists( 'dark_music_pro_add_latest_release_section' ) ) :
    /**
    * Add latest_release section
    *
    *@since Dark Music Pro 1.0.0
    */
    function dark_music_pro_add_latest_release_section() {
    	$options = dark_music_pro_get_theme_options();
        // Check if latest_release is enabled on frontpage
        $latest_release_enable = apply_filters( 'dark_music_pro_section_status', true, 'latest_release_section_enable' );

        if ( true !== $latest_release_enable ) {
            return false;
        }
        // Get latest_release section details
        $section_details = array();
        $section_details = apply_filters( 'dark_music_pro_filter_latest_release_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render latest_release section now.
        dark_music_pro_render_latest_release_section( $section_details );
    }
endif;

if ( ! function_exists( 'dark_music_pro_get_latest_release_section_details' ) ) :
    /**
    * latest_release section details.
    *
    * @since Dark Music Pro 1.0.0
    * @param array $input latest_release section details.
    */
    function dark_music_pro_get_latest_release_section_details( $input ) {
        $options = dark_music_pro_get_theme_options();

        // Content type.
        $latest_release_content_type  = $options['latest_release_content_type'];
        
        $content = array();
        switch ( $latest_release_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['latest_release_content_page_' . $i] ) ) {
                        $page_ids[] = $options['latest_release_content_page_' . $i];
                        $post_subtitle[] = ! empty( $options['latest_release_post_subtitle_' . $i] ) ? $options['latest_release_post_subtitle_' . $i] : '';
                    }
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['latest_release_content_post_' . $i] ) ) {
                        $post_ids[] = $options['latest_release_content_post_' . $i];
                        $post_subtitle[] = ! empty( $options['latest_release_post_subtitle_' . $i] ) ? $options['latest_release_post_subtitle_' . $i] : '';
                    }
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['latest_release_content_category'] ) ? $options['latest_release_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 3,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['latest_release_content_product_' . $i] ) ) {
                        $page_ids[] = $options['latest_release_content_product_' . $i];
                        $post_subtitle[] = ! empty( $options['latest_release_post_subtitle_' . $i] ) ? $options['latest_release_post_subtitle_' . $i] : '';
                    }
                }
                
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['latest_release_content_product_category'] ) ? $options['latest_release_content_product_category'] : '';
                $args = array(
                    'post_type'      => 'product',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 3,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        $i = in_array( $latest_release_content_type, array( 'category', 'product-category' ) ) ? 1 : 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = dark_music_pro_trim_content( 10 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
               
                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest_release section content details.
add_filter( 'dark_music_pro_filter_latest_release_section_details', 'dark_music_pro_get_latest_release_section_details' );


if ( ! function_exists( 'dark_music_pro_render_latest_release_section' ) ) :
  /**
   * Start latest_release section
   *
   * @return string latest_release content
   * @since Dark Music Pro 1.0.0
   *
   */
   function dark_music_pro_render_latest_release_section( $content_details = array() ) {
        $options = dark_music_pro_get_theme_options();
        $latest_release_content_type  = $options['latest_release_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="dark_music_pro_latest_release_section">
            <div id="album-section" class="latest-release-section relative page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    dark_music_pro_section_tooltip( 'latest-release-section-class' );
                    endif; ?>
                    <div class="section-header">
                        <?php if ( !empty( $options['latest_release_subtitle'] ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['latest_release_subtitle'] ); ?></p>
                        <?php endif ?>
                        <?php if ( !empty( $options['latest_release_title'] ) ): ?>
                            <h2 class="section-title"><?php echo esc_html( $options['latest_release_title'] ); ?></h2>
                        <?php endif ?>                    
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                        <?php $i=1; foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="album-item">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="album-image"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php if ( !empty($options['latest_release_post_subtitle_'.$i]) ): ?>
                                        <div class="entry-content">
                                            <p><?php echo esc_html( $options['latest_release_post_subtitle_'.$i] ); ?></p>
                                        </div><!-- .entry-content -->
                                    <?php endif ?>
                                    
                                    <?php if ( !empty( $options['latest_release_btn_title'] ) ): ?>
                                        <div class="read-more">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><i class="fa fa-download"></i><?php echo esc_html( $options['latest_release_btn_title'] ); ?></a>
                                        </div><!-- .read-more -->
                                    <?php endif ?>                               
                                </div><!-- .entry-container -->
                            </div><!-- .album-item -->
                        </article>
                        <?php $i++; endforeach; ?>
                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #album-section -->    
        </div>
        
    <?php }
endif;