<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */
if ( ! function_exists( 'dark_music_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Dark Music Pro 1.0.0
    */
    function dark_music_pro_add_service_section() {
    	$options = dark_music_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'dark_music_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'dark_music_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        dark_music_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'dark_music_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Dark Music Pro 1.0.0
    * @param array $input service section details.
    */
    function dark_music_pro_get_service_section_details( $input ) {
        $options = dark_music_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_count = ! empty( $options['service_count'] ) ? $options['service_count'] : 4;
        
        $content = array();
        switch ( $service_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $service_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = dark_music_pro_trim_content( 20 );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'dark_music_pro_filter_service_section_details', 'dark_music_pro_get_service_section_details' );


if ( ! function_exists( 'dark_music_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Dark Music Pro 1.0.0
   *
   */
   function dark_music_pro_render_service_section( $content_details = array() ) {
        $options = dark_music_pro_get_theme_options();
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="dark_music_pro_service_section">
            <div id="service-section" class="relative page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    dark_music_pro_section_tooltip( 'service-section' );
                    endif; ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['service_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['service_subtitle'] ); ?></p>
                        <?php endif; ?>
                        <?php if ( ! empty( $options['service_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['service_title'] ); ?></h2>
                        <?php endif; ?>  
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="service-item">
                                    <div class="entry-container">
                                        <div class="icon-container">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                <i class="fa <?php echo ! empty( $options['service_content_icon_' . $i] ) ? esc_attr( $options['service_content_icon_' . $i] ) : 'fa-cogs'; ?>"></i>
                                            </a>
                                        </div><!-- .icon-container -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                        <?php if ( !empty( $options['service_btn_title'] ) ): ?>
                                            <div class="read-more">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['service_btn_title'] ); ?></a>
                                            </div><!-- .read-more -->
                                        <?php endif ?>                                    
                                    </div><!-- .entry-container -->
                                </div><!-- .service-item -->
                            </article>
                        <?php $i++; endforeach; ?>
                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #service-section -->
        </div>
       
    <?php }
endif;
