<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Dark Music Pro
 * @since Dark Music Pro 1.0.0
 */
if ( ! function_exists( 'dark_music_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Dark Music Pro 1.0.0
    */
    function dark_music_pro_add_subscription_section() {
    	$options = dark_music_pro_get_theme_options();
        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'dark_music_pro_section_status', true, 'subscription_section_enable' );

        if ( true !== $subscription_enable ) {
            return false;
        }

        // Render subscription section now.
        dark_music_pro_render_subscription_section();
    }
endif;
add_action( 'dark_music_pro_content_end_action', 'dark_music_pro_add_subscription_section', 5 );

if ( ! function_exists( 'dark_music_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Dark Music Pro 1.0.0
   *
   */
   function dark_music_pro_render_subscription_section() {
        $options = dark_music_pro_get_theme_options();
        $bg_image = !empty( $options['subscription_bg_image'] ) ? $options['subscription_bg_image'] : '';

        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }
        ?>
        <div id="dark_music_pro_subscription_section">
            <div id="subscribe-now" class="subscription-section relative page-section" style="background-image: url('<?php echo esc_url( $bg_image ) ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    dark_music_pro_section_tooltip( 'subscription-section-class' );
                    endif; ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['subscription_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['subscription_subtitle'] ); ?></p>
                        <?php endif; ?>
                       <?php if ( ! empty( $options['subscription_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['subscription_title'] ); ?></h2>
                        <?php endif; ?>                    
                    </div><!-- .section-header -->

                    <div class="subscribe-form-wrapper">
                        <?php  
                            $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html__( 'Subscribe', 'dark-music-pro' ) . '" show_subscribers_total="0"]';
                            echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                        ?>
                    </div><!-- .subscribe-form-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #subscribe-now -->
        </div>
        

    <?php }
endif;